@@ -1,7 +1,6 @@
 import logging
-
-from django.core.files.images import ImageFile
 from django.db.models.fields.files import FieldFile, FileField, ImageField
+from django.core.files.images import ImageFile
 
 log = logging.getLogger(__name__)
 
@@ -18,8 +17,8 @@ class DynamicStorageFieldFile(FieldFile):
     """FieldFile implementation for dynamically setting the storage provider for the file at runtime based on a callable passed into the field definition"""
 
     def __init__(self, instance, field, name):
-        if getattr(field, "_storage_callable", None):
-            storage = field._storage_callable(instance)
+        if getattr(field, "storage_instance_callable", None):
+            storage = field.storage_instance_callable(instance)
             log.info("Setting storage for this field to {}".format(storage))
             field.storage = storage
         super().__init__(instance, field, name)
@@ -30,10 +29,15 @@ class DynamicStorageFileField(FileFieldMixin, FileField):
 
     attr_class = DynamicStorageFieldFile
 
+    def __init__(self, *args, **kwargs):
+        if "storage_instance_callable" in kwargs and kwargs.get("storage_instance_callable"):
+            self.storage_instance_callable = kwargs.pop("storage_instance_callable")
+        super().__init__(*args, **kwargs)
+
     def pre_save(self, model_instance, add):
-        if getattr(self, "_storage_callable", None):
-            if callable(self._storage_callable):
-                self.storage = self._storage_callable(model_instance)
+        if getattr(self, "storage_instance_callable", None):
+            if callable(self.storage_instance_callable):
+                self.storage = self.storage_instance_callable(model_instance)
         return super().pre_save(model_instance, add)
 
 
@@ -44,5 +48,5 @@ class DynamicStorageImageFieldFile(ImageFile, DynamicStorageFieldFile):
         super().delete(save)
 
 
-class DynamicStorageImageField(FileFieldMixin, ImageField):
+class DynamicStorageImageField(DynamicStorageFileField, ImageField):
     attr_class = DynamicStorageImageFieldFile
